==> baseui-4.0.0.tgz: package/es/popover/e2e.js <==
'use strict';

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
/* eslint-env node */
/* eslint-disable flowtype/require-valid-file-annotation */
/* global after */

var scenarios = require('./examples-list');

var _require = require('../../e2e/helpers'),
    goToUrl = _require.goToUrl;

var suite = 'Popover Test Suite';

var selectors = {
  tooltip: '[role="tooltip"]'
};

describe('The popover component', function () {
  after(function (browser, done) {
    browser.end(function () {
      return done();
    });
  });

  it('passes basic a11y tests', function (browser) {
    goToUrl({
      suite: suite,
      test: scenarios.SIMPLE_EXAMPLE,
      browser: browser
    }).initAccessibility().waitForElementVisible('body', 1000).assert.accessibility('html', {});
  });

  it('hover opens the popover', function (browser) {
    goToUrl({
      suite: suite,
      test: scenarios.WITH_HOVER,
      browser: browser
    }).waitForElementVisible('body', 1000).moveToElement('button', 10, 10).waitForElementPresent(selectors.tooltip, 1000).moveToElement('body', 10, 10).waitForElementNotPresent(selectors.tooltip, 1000);
  });

  it('opened popover can be closed with ESC', function (browser) {
    goToUrl({
      suite: suite,
      test: scenarios.WITH_CLICK,
      browser: browser
    }).waitForElementVisible('body', 1000).click('button').waitForElementPresent(selectors.tooltip, 1000).keys('\uE00C').waitForElementNotPresent(selectors.tooltip, 1000);
  });
});

==> baseui-5.8.0.tgz: package/es/popover/e2e.js <==
/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/

/* eslint-env node */

/* eslint-disable flowtype/require-valid-file-annotation */

/* global after */
var scenarios = require('./examples-list');

var _require = require('../../e2e/helpers'),
    goToUrl = _require.goToUrl;

var suite = 'Popover Test Suite';
var selectors = {
  tooltip: '[role="tooltip"]'
};
describe('The popover component', function () {
  after(function (browser, done) {
    browser.end(function () {
      return done();
    });
  });
  xit('passes basic a11y tests', function (browser) {
    goToUrl({
      suite: suite,
      test: scenarios.SIMPLE_EXAMPLE,
      browser: browser
    }).initAccessibility().waitForElementVisible('button').assert.accessibility('html', {});
  });
  it('hover opens the popover', function (browser) {
    goToUrl({
      suite: suite,
      test: scenarios.WITH_HOVER,
      browser: browser
    }).waitForElementVisible('button').moveToElement('button', 10, 10).waitForElementPresent(selectors.tooltip).moveToElement('body', 10, 10).waitForElementNotPresent(selectors.tooltip);
  });
  it('opened popover can be closed with ESC', function (browser) {
    goToUrl({
      suite: suite,
      test: scenarios.WITH_CLICK,
      browser: browser
    }).waitForElementVisible('button').click('button').waitForElementPresent(selectors.tooltip).keys("\uE00C").waitForElementNotPresent(selectors.tooltip);
  });
});
